"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.render = exports.App = void 0;
const client_1 = require("@apollo/client");
const ink_1 = require("ink");
const ink_use_stdout_dimensions_1 = __importDefault(require("ink-use-stdout-dimensions"));
const react_1 = __importDefault(require("react"));
const mode_1 = require("../context/mode");
const user_1 = require("../context/user");
const breakpoints_1 = require("../utils/breakpoints");
const graphqlClient_1 = require("../utils/graphqlClient");
const Bold_1 = require("./common/Bold");
const ITermWarning_1 = require("./dialogs/ITermWarning");
const UpdateNotice_1 = require("./dialogs/UpdateNotice");
const RenderIfWindowSize_1 = require("./media-breakpoints/RenderIfWindowSize");
const ModeSwitcher_1 = require("./ModeSwitcher");
const MainPane_1 = require("./panes/MainPane");
const Sidebar_1 = require("./sidebar/Sidebar");
function App({ user }) {
    const [columns, rows] = ink_use_stdout_dimensions_1.default();
    const appFallbackMessage = (react_1.default.createElement(ink_1.Box, { flexDirection: "column", height: rows, width: columns, justifyContent: "center", alignItems: "center" },
        react_1.default.createElement(ink_1.Box, { width: "50%", minWidth: 30, flexDirection: "column" },
            react_1.default.createElement(Bold_1.Bold, null, "Thanks for entering SIGNAL Developer Mode."),
            react_1.default.createElement(ink_1.Text, null, "Developer Mode will automatically adapt to your terminal window size but requires a certain minimum height to work well. Please either increase the size of your window or reduce the text size of your terminal."))));
    return (react_1.default.createElement(client_1.ApolloProvider, { client: graphqlClient_1.client() },
        react_1.default.createElement(user_1.UserProvider, { defaultValue: user },
            react_1.default.createElement(mode_1.ModeProvider, null,
                react_1.default.createElement(ModeSwitcher_1.ModeSwitcher, null),
                react_1.default.createElement(RenderIfWindowSize_1.RenderIfWindowSize, Object.assign({}, breakpoints_1.SHOW_APP, { fallback: appFallbackMessage }),
                    react_1.default.createElement(ink_1.Box, { flexDirection: "column", height: rows, width: columns, padding: 1 },
                        react_1.default.createElement(UpdateNotice_1.CheckUpdateAvailable, null),
                        react_1.default.createElement(ITermWarning_1.ITermWarning, null),
                        react_1.default.createElement(ink_1.Box, { flexDirection: "row", width: "100%", flexGrow: 1 },
                            react_1.default.createElement(Sidebar_1.Sidebar, null),
                            react_1.default.createElement(MainPane_1.MainPane, null))))))));
}
exports.App = App;
exports.render = ({ name, accountSid, twilioUsername, twilioPassword, refreshToken, }, debug = false) => __awaiter(void 0, void 0, void 0, function* () {
    process.title = 'SIGNAL Developer Mode';
    if (!debug) {
        const enterAltScreenCommand = '\x1b[?1049h';
        process.stdout.write(enterAltScreenCommand);
    }
    const { waitUntilExit } = ink_1.render(react_1.default.createElement(App, { user: { name, accountSid, twilioUsername, twilioPassword, refreshToken } }), {
        debug: debug,
    });
    yield waitUntilExit();
    process.exit(0);
});
