"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ModeSwitcher = void 0;
const ink_1 = require("ink");
const react_1 = require("react");
const mode_1 = require("../context/mode");
const modeMachine_1 = require("../machines/modeMachine");
const hotKeyMap = {
    c: modeMachine_1.ModeEvents.showClosedCaptioning,
    k: modeMachine_1.ModeEvents.showClosedCaptioning,
    s: modeMachine_1.ModeEvents.showSchedule,
    q: modeMachine_1.ModeEvents.exit,
    r: modeMachine_1.ModeEvents.showResources,
    d: modeMachine_1.ModeEvents.showDemos,
    // t: ModeEvents.showTest,
    w: modeMachine_1.ModeEvents.showWelcome,
    b: modeMachine_1.ModeEvents.toggleSideBar,
    ['?']: modeMachine_1.ModeEvents.toggleSideBar,
};
const UP = 'U';
const DOWN = 'D';
const LEFT = 'L';
const RIGHT = 'R';
const SEQUENCE = [UP, UP, DOWN, DOWN, LEFT, RIGHT, LEFT, RIGHT, 'B', 'A'].join('');
function getKey(input, key) {
    if (key.upArrow) {
        return UP;
    }
    else if (key.downArrow) {
        return DOWN;
    }
    else if (key.leftArrow) {
        return LEFT;
    }
    else if (key.rightArrow) {
        return RIGHT;
    }
    if (input.toUpperCase() === 'A' || input.toUpperCase() === 'B') {
        return input.toUpperCase();
    }
    return null;
}
function ModeSwitcher() {
    const { exit } = ink_1.useApp();
    const { state, dispatch } = mode_1.useMode();
    const [currentCodeInput, setCurrentCodeInput] = react_1.useState('');
    ink_1.useInput((input, key) => {
        const currentKey = getKey(input, key);
        const nextValidKey = SEQUENCE[currentCodeInput.length];
        if (SEQUENCE.startsWith(currentCodeInput) &&
            currentKey !== null &&
            nextValidKey === currentKey) {
            const newCurrentCode = `${currentCodeInput}${currentKey}`;
            if (SEQUENCE === newCurrentCode) {
                dispatch({ type: modeMachine_1.ModeEvents.showCheatMode });
                return;
            }
            else {
                setCurrentCodeInput(newCurrentCode);
                if (newCurrentCode.endsWith('B')) {
                    // don't toggle the sidebar
                    return;
                }
            }
        }
        else {
            setCurrentCodeInput('');
        }
        if (state.matches('captureInput.on')) {
            if (hotKeyMap[input]) {
                dispatch({ type: hotKeyMap[input] });
            }
        }
    });
    react_1.useEffect(() => {
        if (state.matches('mainPane.exit')) {
            exit();
        }
    }, [state.value]);
    return null;
}
exports.ModeSwitcher = ModeSwitcher;
