"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Animation = void 0;
const react_1 = require("react");
const useAnimation_1 = require("../../hooks/useAnimation");
exports.Animation = ({ frames, intervalSpeed, onDone, children, }) => {
    const { shouldAnimate } = useAnimation_1.useAnimation();
    const [currentFrameIdx, setCurrentFrameIdx] = react_1.useState(0);
    const [isDone, setIsDone] = react_1.useState(!shouldAnimate);
    react_1.useEffect(() => {
        if (currentFrameIdx === frames.length) {
            setIsDone(true);
        }
    }, [currentFrameIdx]);
    react_1.useEffect(() => {
        if (isDone) {
            if (typeof onDone === 'function') {
                onDone();
            }
        }
    }, []);
    react_1.useEffect(() => {
        if (isDone) {
            if (typeof onDone === 'function') {
                onDone();
            }
        }
    }, [isDone]);
    react_1.useEffect(() => {
        let intervalTimer = undefined;
        if (typeof intervalTimer !== 'undefined') {
            clearInterval(intervalTimer);
        }
        if (!shouldAnimate) {
            setIsDone(true);
            return;
        }
        intervalTimer = setInterval(() => {
            setCurrentFrameIdx((currentIdx) => {
                const result = currentIdx + 1;
                if (currentIdx === frames.length) {
                    if (intervalTimer) {
                        clearInterval(intervalTimer);
                    }
                }
                return result;
            });
        }, intervalSpeed);
        return () => {
            if (intervalTimer) {
                clearInterval(intervalTimer);
            }
        };
    }, [intervalSpeed, frames, shouldAnimate]);
    if (isDone) {
        const lastFrame = frames[frames.length - 1];
        return children(lastFrame);
    }
    return children(frames[currentFrameIdx]);
};
