"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.InstallationProcess = exports.useDefaultValues = exports.wrappedPromise = void 0;
const react_1 = require("@xstate/react");
const ink_1 = require("ink");
const react_2 = __importStar(require("react"));
const user_1 = require("../../context/user");
const installerMachine_1 = require("../../machines/installerMachine");
const installer_1 = require("../../utils/installer");
const Key_1 = require("../common/Key");
const Selectable_1 = require("../common/Selectable");
const InstallationSummary_1 = require("./InstallationSummary");
const DownloadProjectQuestions_1 = require("./questions/DownloadProjectQuestions");
const GetAndCreateDirectoryQuestions_1 = require("./questions/GetAndCreateDirectoryQuestions");
const InstallDependenciesQuestions_1 = require("./questions/InstallDependenciesQuestions");
const SetupProjectQuestions_1 = require("./questions/SetupProjectQuestions");
const ResultOutput_1 = require("./ResultOutput");
const StepIndicator_1 = require("./StepIndicator");
function wrappedPromise(promise) {
    return promise.catch((err) => {
        throw err;
    });
}
exports.wrappedPromise = wrappedPromise;
function useDefaultValues() {
    const user = user_1.useUser();
    const defaultValues = {
        TWILIO_ACCOUNT_SID: user.accountSid,
        ACCOUNT_SID: user.accountSid,
    };
    const twilioUsername = user.twilioUsername;
    if (twilioUsername !== null && (twilioUsername === null || twilioUsername === void 0 ? void 0 : twilioUsername.startsWith('AC'))) {
        defaultValues['TWILIO_AUTH_TOKEN'] = user.twilioPassword;
        defaultValues['AUTH_TOKEN'] = user.twilioPassword;
    }
    else {
        defaultValues['TWILIO_API_KEY'] = user.twilioUsername;
        defaultValues['TWILIO_API_SECRET'] = user.twilioPassword;
    }
    return defaultValues;
}
exports.useDefaultValues = useDefaultValues;
function getStepStatuses(currentState) {
    const { results } = currentState.context;
    const statusMap = {
        createDirectory: 'todo',
        download: 'todo',
        installDependencies: 'todo',
        configure: 'todo',
    };
    if (currentState.matches('askingForDirectory')) {
        statusMap.createDirectory = 'active';
        return statusMap;
    }
    if (currentState.matches('creatingDirectory')) {
        statusMap.createDirectory = 'running';
        return statusMap;
    }
    statusMap.createDirectory =
        !!results.createDirectory && results.createDirectory.skipped
            ? 'skipped'
            : results.createDirectory
                ? 'success'
                : 'error';
    if (currentState.matches('confirmingDownload')) {
        statusMap.download = 'active';
        return statusMap;
    }
    if (currentState.matches('downloading')) {
        statusMap.download = 'running';
        return statusMap;
    }
    statusMap.download =
        !!results.download && results.download.skipped
            ? 'skipped'
            : results.download
                ? 'success'
                : 'error';
    if (currentState.matches('confirmInstallingDependencies')) {
        statusMap.installDependencies = 'active';
        return statusMap;
    }
    if (currentState.matches('installingDependencies')) {
        statusMap.installDependencies = 'running';
        return statusMap;
    }
    statusMap.installDependencies =
        !!results.installDependencies && results.installDependencies.skipped
            ? 'skipped'
            : results.installDependencies
                ? 'success'
                : 'error';
    if (currentState.matches('confirmConfiguring')) {
        statusMap.configure = 'active';
        return statusMap;
    }
    if (currentState.matches('configuring')) {
        statusMap.configure = 'running';
        return statusMap;
    }
    statusMap.configure =
        !!results.configure && results.configure.skipped
            ? 'skipped'
            : results.configure
                ? 'success'
                : 'error';
    return statusMap;
}
function InstallationProcess({ repoUrl, language, onDone, slim, shouldRenderDetails = true, }) {
    const defaultConfigValues = useDefaultValues();
    const [currentState, send, service] = react_1.useMachine(installerMachine_1.installerMachine, {
        services: {
            createDirectory: (context) => context.directory
                ? wrappedPromise(installer_1.getAndCreateDirectory(context.directory))
                : Promise.reject(new Error('Something went wrong')),
            download: (context) => context.repoUrl && context.directory
                ? wrappedPromise(installer_1.download(context.repoUrl, context.directory, { force: true }))
                : Promise.reject(new Error('Something went wrong')),
            installDependencies: (context) => {
                var _a, _b, _c, _d;
                return context.directory && context.language
                    ? wrappedPromise(installer_1.installDependencies(context.directory, context.language, (_b = (_a = context.results) === null || _a === void 0 ? void 0 : _a.download) === null || _b === void 0 ? void 0 : _b.hasPackageJson, (_d = (_c = context.results) === null || _c === void 0 ? void 0 : _c.download) === null || _d === void 0 ? void 0 : _d.hasMakeFile))
                    : Promise.reject(new Error('Something went wrong'));
            },
            configure: (context) => context.directory && context.results.parsedResult
                ? wrappedPromise(installer_1.setupProject(context.directory, context.results.parsedResult, context.results.parsedResult.answers))
                : Promise.reject(new Error('Something went wrong')),
        },
        context: {
            repoUrl,
            language,
            isEmptyDirectory: undefined,
            directory: undefined,
        },
    });
    react_2.useEffect(() => {
        service.onDone(({ data }) => {
            onDone(data);
        });
    }, [service]);
    react_2.useEffect(() => {
        if (currentState.matches('failure.error')) {
            onDone({ successful: false });
        }
    }, [currentState.value]);
    ink_1.useInput((_, key) => {
        if (key.return) {
            send('RESTART');
        }
        else if (key.escape) {
            send('FINISH');
        }
    }, { isActive: currentState.matches('failure.cancelled') });
    const stepStatusMap = react_2.useMemo(() => getStepStatuses(currentState), [
        currentState,
    ]);
    return (react_2.default.createElement(ink_1.Box, { flexDirection: "column", flexGrow: 1, width: "100%" },
        react_2.default.createElement(StepIndicator_1.StepIndicator, { slim: slim, title: "1. Specify installation location", status: stepStatusMap.createDirectory, shouldRenderDetails: shouldRenderDetails },
            currentState.matches('askingForDirectory') && (react_2.default.createElement(GetAndCreateDirectoryQuestions_1.GetAndCreateDirectoryQuestions, { dispatch: send })),
            currentState.context.results.createDirectory && (react_2.default.createElement(ResultOutput_1.ResultOutput, { result: currentState.context.results.createDirectory }))),
        react_2.default.createElement(StepIndicator_1.StepIndicator, { slim: slim, title: "2. Downloading sample", status: stepStatusMap.download, shouldRenderDetails: shouldRenderDetails },
            currentState.matches('confirmingDownload') && (react_2.default.createElement(DownloadProjectQuestions_1.DownloadProjectQuestions, { dispatch: send, context: currentState.context })),
            currentState.context.results.download && (react_2.default.createElement(ResultOutput_1.ResultOutput, { result: currentState.context.results.download }))),
        react_2.default.createElement(StepIndicator_1.StepIndicator, { slim: slim, title: "3. Installing dependencies", status: stepStatusMap.installDependencies, shouldRenderDetails: shouldRenderDetails },
            currentState.matches('confirmInstallingDependencies') && (react_2.default.createElement(InstallDependenciesQuestions_1.InstallDependenciesQuestions, { dispatch: send })),
            currentState.context.results.installDependencies && (react_2.default.createElement(ResultOutput_1.ResultOutput, { result: currentState.context.results.installDependencies }))),
        react_2.default.createElement(StepIndicator_1.StepIndicator, { slim: slim, title: "4. Setting up project", status: stepStatusMap.configure, shouldRenderDetails: shouldRenderDetails },
            currentState.matches('confirmConfiguring') &&
                currentState.context.directory && (react_2.default.createElement(SetupProjectQuestions_1.SetupProjectQuestions, { directory: currentState.context.directory, dispatch: send, defaultValues: defaultConfigValues })),
            currentState.context.results.configure && (react_2.default.createElement(ResultOutput_1.ResultOutput, { result: currentState.context.results.configure }))),
        currentState.matches('success') && currentState.context.directory && (react_2.default.createElement(StepIndicator_1.StepIndicator, { slim: slim, title: "5. Project Ready" },
            react_2.default.createElement(InstallationSummary_1.InstallationSummary, { directory: currentState.context.directory }))),
        currentState.matches('failure') && (react_2.default.createElement(StepIndicator_1.StepIndicator, { slim: slim, title: "Failed to setup project" },
            react_2.default.createElement(ink_1.Box, { flexDirection: "column" },
                react_2.default.createElement(ink_1.Box, { flexDirection: "column" },
                    currentState.matches('failure') && (react_2.default.createElement(ink_1.Text, null, currentState.meta['installer.failure'].message)),
                    currentState.matches('failure.error') && (react_2.default.createElement(ink_1.Text, null, currentState.context.error.join('\n')))),
                currentState.matches('failure.cancelled') && (react_2.default.createElement(ink_1.Box, { flexDirection: "column" },
                    react_2.default.createElement(ink_1.Text, null,
                        "Do you want to try again? Press ",
                        react_2.default.createElement(Key_1.Key, null, "Esc"),
                        " otherwise."),
                    react_2.default.createElement(Selectable_1.Selectable, { active: true }, "Retry"))))))));
}
exports.InstallationProcess = InstallationProcess;
