"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.StepIndicator = exports.StatusIndicator = void 0;
const figures_1 = __importDefault(require("figures"));
const ink_1 = require("ink");
const react_1 = __importDefault(require("react"));
const Bold_1 = require("../common/Bold");
const LoadingIndicator_1 = require("../common/LoadingIndicator");
function StatusIndicator({ status, children }) {
    switch (status) {
        case 'skipped':
            return (react_1.default.createElement(Bold_1.Bold, null,
                react_1.default.createElement(ink_1.Text, { color: "yellow" }, figures_1.default.arrowDown),
                " ",
                children,
                ' ',
                react_1.default.createElement(ink_1.Text, { dimColor: true }, "[skipped]")));
        case 'error':
            return (react_1.default.createElement(Bold_1.Bold, null,
                react_1.default.createElement(ink_1.Text, { color: "redBright" }, figures_1.default.cross),
                " ",
                children,
                ' ',
                react_1.default.createElement(ink_1.Text, { dimColor: true }, "[error]")));
        case 'success':
            return (react_1.default.createElement(Bold_1.Bold, null,
                react_1.default.createElement(ink_1.Text, { color: "greenBright" }, figures_1.default.tick),
                " ",
                children,
                ' ',
                react_1.default.createElement(ink_1.Text, { dimColor: true }, "[done]")));
        case 'running':
            return (react_1.default.createElement(Bold_1.Bold, null,
                children,
                " ",
                react_1.default.createElement(ink_1.Text, { dimColor: true },
                    "[in progress",
                    figures_1.default.ellipsis,
                    "]")));
        case 'todo':
            return (react_1.default.createElement(Bold_1.Bold, { dimColor: true },
                react_1.default.createElement(ink_1.Text, { color: "gray" }, figures_1.default.nodejs),
                '  ',
                children));
    }
    return react_1.default.createElement(Bold_1.Bold, null, children);
}
exports.StatusIndicator = StatusIndicator;
function StepIndicator({ title, children, status = 'active', slim = true, shouldRenderDetails = true, }) {
    const active = status === 'active' || status === 'running';
    const running = status === 'running';
    const borderStyle = active ? 'single' : slim ? undefined : 'single';
    const paddingY = slim ? 0 : 1;
    const renderDetails = status === 'active' ? true : shouldRenderDetails;
    return (react_1.default.createElement(ink_1.Box, { width: "100%", flexDirection: "column", borderStyle: borderStyle, borderColor: active ? undefined : 'gray', marginBottom: renderDetails ? 1 : 0, paddingY: paddingY, paddingX: 1 },
        react_1.default.createElement(ink_1.Box, null,
            react_1.default.createElement(StatusIndicator, { status: status }, title)),
        renderDetails && (react_1.default.createElement(react_1.default.Fragment, null,
            running && react_1.default.createElement(LoadingIndicator_1.LoadingIndicator, { text: "Loading..." }),
            children))));
}
exports.StepIndicator = StepIndicator;
