"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.InspectorResourceView = void 0;
const date_fns_1 = require("date-fns");
const ink_1 = require("ink");
const react_1 = __importStar(require("react"));
const mode_1 = require("../../context/mode");
const demoEntryMachine_1 = require("../../machines/demoEntryMachine");
const modeMachine_1 = require("../../machines/modeMachine");
const openLink_1 = require("../../utils/openLink");
const InteractiveDemoEntry_1 = require("../demo/InteractiveDemoEntry");
const ResourceLinkBox_1 = require("./ResourceLinkBox");
function getInfoForTime(inspectorData, time) {
    const resource = inspectorData.xray.resources.find((r) => r.startTime <= time && r.endTime >= time);
    if (!resource) {
        return null;
    }
    let demo = undefined;
    if (resource.demo.length > 0) {
        const demoData = inspectorData.demos.demos[resource.demo[0]];
        if (demoData) {
            demo = Object.assign(Object.assign({}, demoData), { key: resource.demo[0] });
        }
    }
    return Object.assign(Object.assign({}, resource), { demo });
}
function InspectorResourceViewWrapper({ time, endTime, children, }) {
    const relativeTime = endTime > time
        ? date_fns_1.formatDistance(endTime, time, {
            includeSeconds: true,
            addSuffix: true,
        })
        : 'soon';
    return (react_1.default.createElement(ink_1.Box, { flexDirection: "column" },
        react_1.default.createElement(ink_1.Box, { paddingX: 2 },
            react_1.default.createElement(ink_1.Text, { dimColor: true },
                "Next resource ",
                relativeTime)),
        children));
}
function InspectorResourceView({ inspectorData, time, slim = false, }) {
    const { dispatch } = mode_1.useMode();
    const resource = getInfoForTime(inspectorData, time);
    const onDemoOptionSelect = react_1.useCallback((chosenOption, languageIdx) => {
        const selectedDemo = resource === null || resource === void 0 ? void 0 : resource.demo;
        if (!selectedDemo) {
            return;
        }
        if (chosenOption === demoEntryMachine_1.DemoEntryOptions.DOWNLOAD) {
            dispatch({
                type: modeMachine_1.ModeEvents.showInstaller,
                data: Object.assign(Object.assign({}, selectedDemo), selectedDemo === null || selectedDemo === void 0 ? void 0 : selectedDemo.options[languageIdx]),
            });
        }
        else if (chosenOption === demoEntryMachine_1.DemoEntryOptions.LEARN_MORE) {
            openLink_1.openBrowserUrl(selectedDemo === null || selectedDemo === void 0 ? void 0 : selectedDemo.codeexchange_link);
        }
        else if (chosenOption === demoEntryMachine_1.DemoEntryOptions.VIEW_CODE) {
            const codeLink = selectedDemo.options[languageIdx].repo_link ||
                selectedDemo.options[languageIdx].functions_link;
            if (codeLink) {
                openLink_1.openBrowserUrl(codeLink);
            }
        }
        else if (chosenOption === demoEntryMachine_1.DemoEntryOptions.QUICK_DEPLOY && (selectedDemo === null || selectedDemo === void 0 ? void 0 : selectedDemo.quick_deploy_link)) {
            openLink_1.openBrowserUrl(selectedDemo === null || selectedDemo === void 0 ? void 0 : selectedDemo.quick_deploy_link);
        }
    }, [resource === null || resource === void 0 ? void 0 : resource.demo]);
    if (!resource) {
        return null;
    }
    if (resource.demo) {
        return (react_1.default.createElement(InspectorResourceViewWrapper, { time: time, endTime: resource.endTime },
            react_1.default.createElement(InteractiveDemoEntry_1.InteractiveDemoEntry, { demo: resource.demo, onSelect: onDemoOptionSelect, slim: slim })));
    }
    if (resource.links[0]) {
        return (react_1.default.createElement(InspectorResourceViewWrapper, { time: time, endTime: resource.endTime },
            react_1.default.createElement(ResourceLinkBox_1.ResourceLinkBox, { link: resource.links[0], slim: slim })));
    }
    return (react_1.default.createElement(InspectorResourceViewWrapper, { time: time, endTime: resource.endTime }));
}
exports.InspectorResourceView = InspectorResourceView;
