"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DemoPane = exports.DemoSelection = void 0;
const ink_1 = require("ink");
const react_1 = __importStar(require("react"));
const mode_1 = require("../../context/mode");
const useApi_1 = require("../../hooks/useApi");
const useScrollableList_1 = require("../../hooks/useScrollableList");
const modeMachine_1 = require("../../machines/modeMachine");
const breakpoints_1 = require("../../utils/breakpoints");
const openLink_1 = require("../../utils/openLink");
const Bold_1 = require("../common/Bold");
const Key_1 = require("../common/Key");
const ListSelector_1 = require("../common/ListSelector");
const LoadingIndicator_1 = require("../common/LoadingIndicator");
const DemoEntryBox_1 = require("../demo/DemoEntryBox");
const InteractiveDemoEntry_1 = require("../demo/InteractiveDemoEntry");
const ScrollableItemList_1 = require("../scrollable/ScrollableItemList");
const Pane_1 = require("./Pane");
const PaneContent_1 = require("./PaneContent");
const DemoRow = ({ demo, active }) => {
    return (react_1.default.createElement(ink_1.Box, null,
        react_1.default.createElement(ListSelector_1.ListSelector, { active: active }),
        react_1.default.createElement(ink_1.Text, { wrap: "truncate-end" }, demo.name),
        demo.products.length > 0 && (react_1.default.createElement(ink_1.Text, { dimColor: true },
            " | ",
            demo.products.join(', ')))));
};
const DemoList = ({ demos, activeIdx }) => {
    const activeKey = demos[activeIdx].key;
    return (react_1.default.createElement(ScrollableItemList_1.ScrollableItemList, { activeIdx: activeIdx }, demos.map((demo) => {
        return (react_1.default.createElement(DemoRow, { demo: demo, active: activeKey === demo.key, key: demo.key }));
    })));
};
exports.DemoSelection = ({ demos }) => {
    const { dispatch } = mode_1.useMode();
    const [selectedDemoIdx] = useScrollableList_1.useScrollableList(0, demos, Array.isArray(demos));
    const selectedDemo = Array.isArray(demos)
        ? demos[selectedDemoIdx]
        : undefined;
    const handleSelect = react_1.useCallback((chosenOption, languageIdx) => {
        if (chosenOption === DemoEntryBox_1.DemoEntryOptions.DOWNLOAD) {
            dispatch({
                type: modeMachine_1.ModeEvents.showInstaller,
                data: Object.assign(Object.assign({}, selectedDemo), selectedDemo === null || selectedDemo === void 0 ? void 0 : selectedDemo.options[languageIdx]),
            });
        }
        else if (chosenOption === DemoEntryBox_1.DemoEntryOptions.LEARN_MORE) {
            openLink_1.openBrowserUrl(selectedDemo === null || selectedDemo === void 0 ? void 0 : selectedDemo.codeexchange_link);
        }
        else if (chosenOption === DemoEntryBox_1.DemoEntryOptions.VIEW_CODE) {
            if (selectedDemo === null || selectedDemo === void 0 ? void 0 : selectedDemo.options[languageIdx]) {
                openLink_1.openBrowserUrl(selectedDemo.options[languageIdx].repo_link ||
                    selectedDemo.options[languageIdx].functions_link);
            }
        }
        else if (chosenOption === DemoEntryBox_1.DemoEntryOptions.QUICK_DEPLOY) {
            openLink_1.openBrowserUrl(selectedDemo === null || selectedDemo === void 0 ? void 0 : selectedDemo.quick_deploy_link);
        }
    }, [selectedDemo]);
    return (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement(ink_1.Text, null,
            "Use arrow keys to navigate and hit ",
            react_1.default.createElement(Key_1.Key, null, "Return"),
            "/",
            react_1.default.createElement(Key_1.Key, null, "Enter"),
            " to select an option. Press ",
            react_1.default.createElement(Key_1.Key, null, "Tab"),
            " to cycle between programming languages."),
        react_1.default.createElement(DemoList, { demos: demos, activeIdx: selectedDemoIdx }),
        selectedDemo && (react_1.default.createElement(InteractiveDemoEntry_1.InteractiveDemoEntry, { demo: selectedDemo, onSelect: handleSelect }))));
};
exports.DemoPane = () => {
    const { demos, loading, error, } = useApi_1.useDemos();
    const sortedDemos = react_1.useMemo(() => demos === null || demos === void 0 ? void 0 : demos.sort((a, b) => a.name.localeCompare(b.name)), [demos]);
    return (react_1.default.createElement(Pane_1.Pane, { headline: "Demos" },
        react_1.default.createElement(PaneContent_1.PaneContent, { breakpoint: breakpoints_1.SHOW_DEMO_SECTION },
            react_1.default.createElement(Bold_1.Bold, null, "Explore what's possible with Twilio"),
            loading && react_1.default.createElement(LoadingIndicator_1.LoadingIndicator, { text: "Loading demos..." }),
            error && react_1.default.createElement(ink_1.Text, null, error === null || error === void 0 ? void 0 : error.message),
            !loading && sortedDemos && react_1.default.createElement(exports.DemoSelection, { demos: sortedDemos }))));
};
