"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.InstallerPane = void 0;
const ink_1 = require("ink");
const open_1 = __importDefault(require("open"));
const react_1 = __importStar(require("react"));
const mode_1 = require("../../context/mode");
const useResize_1 = require("../../hooks/useResize");
const useTerminalInfo_1 = require("../../hooks/useTerminalInfo");
const modeMachine_1 = require("../../machines/modeMachine");
const breakpoints_1 = require("../../utils/breakpoints");
const Info_1 = require("../common/Info");
const Key_1 = require("../common/Key");
const DemoEntryBox_1 = require("../demo/DemoEntryBox");
const InstallationProcess_1 = require("../installer/InstallationProcess");
const OpenProjectBox_1 = require("../installer/OpenProjectBox");
const PaneContent_1 = require("./PaneContent");
const fallbackInstaller = (react_1.default.createElement(ink_1.Text, null,
    "Your terminal is too small to support the best experience for the demo installer. Try hiding the sidebar using ",
    react_1.default.createElement(Key_1.Key, null, "Ctrl"),
    "+",
    react_1.default.createElement(Key_1.Key, null, "b"),
    " or increase the size of your terminal until this message disappears."));
function HasNoGit({ url }) {
    return (react_1.default.createElement(ink_1.Text, null,
        "We are sorry, we could not find git installed on your system. This is required for the installer to work. Please either install git and restart Developer Mode or download the code manually from ",
        url));
}
function InstallerInfo() {
    return (react_1.default.createElement(ink_1.Text, null,
        react_1.default.createElement(Info_1.Info, { text: "Info" }),
        " You can exit the installer at any point by pressing",
        ' ',
        react_1.default.createElement(Key_1.Key, null, "Ctrl"),
        " + ",
        react_1.default.createElement(Key_1.Key, null, "D")));
}
exports.InstallerPane = () => {
    const [projectDir, setProjectDir] = react_1.useState(undefined);
    const [installationDone, setInstallationDone] = react_1.useState(false);
    const [installationSuccessful, setInstallationSuccessful] = react_1.useState(false);
    const { state, dispatch } = mode_1.useMode();
    const { hasGit } = useTerminalInfo_1.useTerminalInfo();
    const { height } = useResize_1.useResponsiveWindowSize();
    const slim = (height || 0) < 51;
    const noDetails = (height || 0) < 30;
    const openProject = react_1.useCallback(() => {
        if (installationDone && projectDir) {
            open_1.default(projectDir);
        }
    }, [installationDone, projectDir]);
    ink_1.useInput((input, key) => {
        if (key.ctrl && input === 'd') {
            dispatch({ type: modeMachine_1.ModeEvents.exitInstaller });
        }
        if (key.ctrl && input === 'b') {
            dispatch({ type: modeMachine_1.ModeEvents.toggleSideBar });
        }
    });
    const selectedDemo = state.context.selectedDemo;
    if (!selectedDemo) {
        return null;
    }
    const onDone = ({ directory, successful, }) => {
        setInstallationDone(true);
        setInstallationSuccessful(successful);
        setProjectDir(directory);
        dispatch({ type: modeMachine_1.ModeEvents.finished });
    };
    if (selectedDemo.repo_link === null) {
        return null;
    }
    return (react_1.default.createElement(PaneContent_1.PaneContent, { width: "100%", fallback: fallbackInstaller, breakpoint: breakpoints_1.SHOW_INSTALLER },
        !hasGit && react_1.default.createElement(HasNoGit, { url: selectedDemo.repo_link }),
        hasGit && (react_1.default.createElement(react_1.default.Fragment, null,
            react_1.default.createElement(DemoEntryBox_1.DemoEntryBox, { demo: selectedDemo, language: selectedDemo.language, minHeight: 5, height: 5, borderStyle: undefined },
                react_1.default.createElement(InstallerInfo, null)),
            react_1.default.createElement(InstallationProcess_1.InstallationProcess, { slim: slim, language: selectedDemo.language, repoUrl: selectedDemo.repo_link, onDone: onDone, shouldRenderDetails: !noDetails }),
            installationDone && installationSuccessful && (react_1.default.createElement(OpenProjectBox_1.OpenProjectBox, { slim: slim, onOpen: openProject }))))));
};
