"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ResourcePane = void 0;
const ink_1 = require("ink");
const react_1 = __importDefault(require("react"));
const useScrollableList_1 = require("../../hooks/useScrollableList");
const openLink_1 = require("../../utils/openLink");
const ListSelector_1 = require("../common/ListSelector");
const ScrollableItemList_1 = require("../scrollable/ScrollableItemList");
const Pane_1 = require("./Pane");
const PaneContent_1 = require("./PaneContent");
const RESOURCES = [
    {
        key: 'twilio',
        name: 'Twilio',
        url: 'https://www.twilio.com',
        description: 'Visit the Twilio Website.',
    },
    {
        key: 'tq',
        name: 'TwilioQuest',
        url: 'https://www.twilio.com/quest',
        description: `Twilio's video game to teach you coding.`,
    },
    {
        key: 'signal',
        name: 'SIGNAL Website',
        url: 'https://www.twilio.com/signal',
        description: 'View live and on-demand SIGNAL 2020 sessions.',
    },
    {
        key: 'codeexchange',
        name: 'Twilio CodeExchange',
        url: 'https://www.twilio.com/code-exchange',
        description: 'Find code for various use cases you can build with Twilio.',
    },
    {
        key: 'signal-tv',
        name: 'SIGNAL TV',
        url: 'https://twitch.tv/twilio',
        description: 'Watch live coverage of SIGNAL 2020.',
    },
    {
        key: 'twilio-docs',
        name: 'Twilio Docs',
        url: 'https://www.twilio.com/docs',
        description: 'Find the documentation to all of our Twilio products.',
    },
    {
        key: 'dev-mode-introduction',
        name: 'SIGNAL Developer Mode',
        url: 'https://www.twilio.com/blog/signal-developer-mode',
        description: 'Read more on how to use SIGNAL Developer Mode',
    },
    {
        key: 'troubleshooting',
        name: 'SIGNAL Developer Mode Troubleshooting',
        url: 'https://github.com/twilio-labs/plugin-signal2020/blob/main/docs/TROUBLESHOOTING.md',
        description: 'Read our troubleshooting guide for SIGNAL Developer Mode',
    },
    {
        key: 'how-its-built',
        name: 'How we built a CLI for a conference',
        url: 'https://www.twilio.com/blog/building-conference-cli-in-react',
        description: 'Learn how we built the SIGNAL Developer Mode using React',
    },
    {
        key: 'source-code',
        name: 'Developer Mode Source Code',
        url: 'https://github.com/twilio-labs/plugin-signal2020',
        description: 'View the source and general documentation of SIGNAL Developer Mode',
    },
];
function ResourceRow({ name, description, active }) {
    return (react_1.default.createElement(ink_1.Text, { wrap: "truncate-end" },
        react_1.default.createElement(ListSelector_1.ListSelector, { active: active }),
        react_1.default.createElement(ink_1.Text, null,
            react_1.default.createElement(ink_1.Text, { bold: true }, name),
            " ",
            react_1.default.createElement(ink_1.Text, { dimColor: true },
                "| ",
                description))));
}
function ResourcePane() {
    const resources = RESOURCES;
    const [activeEntry] = useScrollableList_1.useScrollableList(0, resources);
    ink_1.useInput((input, key) => {
        if (resources[activeEntry] && resources[activeEntry].url) {
            if (key.return) {
                openLink_1.openBrowserUrl(RESOURCES[activeEntry].url);
            }
        }
    });
    return (react_1.default.createElement(Pane_1.Pane, { headline: "Resources" },
        react_1.default.createElement(PaneContent_1.PaneContent, null,
            react_1.default.createElement(ScrollableItemList_1.ScrollableItemList, { activeIdx: activeEntry }, RESOURCES.map((res, idx) => {
                return (react_1.default.createElement(ResourceRow, { key: res.key, name: res.name, description: res.description, active: idx === activeEntry }));
            })))));
}
exports.ResourcePane = ResourcePane;
