"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Schedule = void 0;
const ink_1 = require("ink");
const react_1 = __importStar(require("react"));
const useScrollableList_1 = require("../../../hooks/useScrollableList");
const openLink_1 = require("../../../utils/openLink");
const scheduleUtils_1 = require("../../../utils/scheduleUtils");
const ScheduleContent_1 = require("./ScheduleContent");
const ScheduleTab_1 = require("./ScheduleTab");
const SessionDetails_1 = require("./SessionDetails");
function Schedule({ sessions, calendarSessions, unregister, register, }) {
    const groupedSessions = react_1.useMemo(() => {
        const grouped = scheduleUtils_1.groupSessionsByTypeOrDate(sessions);
        return grouped;
    }, [sessions]);
    const days = Object.keys(groupedSessions).sort();
    // const [registeredSessions, setRegisteredSessions] = useState(
    // );
    const registeredSessions = react_1.useMemo(() => new Set(calendarSessions.map((x) => x.id)), [calendarSessions]);
    const [selectedDay, setSelectedDay] = react_1.useState(0);
    const [selectedSession, setSelectedSession] = useScrollableList_1.useScrollableList(0, groupedSessions[days[selectedDay]]);
    const [updatingSesions, setUpdatingSessions] = react_1.useState([]);
    react_1.useEffect(() => {
        if (registeredSessions) {
            setUpdatingSessions((current) => {
                return current.filter(({ id, type }) => type === 'registering'
                    ? !registeredSessions.has(id)
                    : registeredSessions.has(id));
            });
        }
    }, [registeredSessions]);
    ink_1.useInput((input, key) => {
        if (key.leftArrow) {
            setSelectedSession(0);
            setSelectedDay((currentDay) => Math.max(0, currentDay - 1));
            return;
        }
        if (key.rightArrow) {
            setSelectedSession(0);
            setSelectedDay((currentDay) => Math.min(currentDay + 1, days.length - 1));
            return;
        }
        if (key.return) {
            const session = groupedSessions[days[selectedDay]][selectedSession];
            if (session.url) {
                openLink_1.openBrowserUrl(session.url);
            }
            else {
                openLink_1.openSessionUrl(session.id);
            }
        }
        if (input === ' ') {
            const session = groupedSessions[days[selectedDay]][selectedSession];
            if (session.canRegister) {
                if (registeredSessions.has(session.id)) {
                    setUpdatingSessions((current) => [
                        ...current,
                        { id: session.id, type: 'unregistering' },
                    ]),
                        unregister(session.id);
                }
                else {
                    setUpdatingSessions((current) => [
                        ...current,
                        { id: session.id, type: 'registering' },
                    ]),
                        register(session.id);
                }
            }
        }
    });
    const selectedSessionInstance = groupedSessions[days[selectedDay]][selectedSession];
    return (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement(ink_1.Box, { flexDirection: "column", flexGrow: 1, justifyContent: "flex-start" },
            react_1.default.createElement(ink_1.Box, { flexDirection: "row", justifyContent: "space-around", paddingLeft: 4, paddingRight: 4 }, days.map((day) => (react_1.default.createElement(ScheduleTab_1.ScheduleTab, { key: day, day: day, active: days[selectedDay] === day })))),
            react_1.default.createElement(ink_1.Box, { flexGrow: 1, flexShrink: 1 },
                react_1.default.createElement(ScheduleContent_1.ScheduleContent, { sessions: groupedSessions[days[selectedDay]], activeSessionIdx: selectedSession, registeredSessions: registeredSessions })),
            react_1.default.createElement(ink_1.Box, { height: 10 },
                react_1.default.createElement(SessionDetails_1.SessionDetails, { session: selectedSessionInstance, registered: registeredSessions.has(selectedSessionInstance.id), updating: updatingSesions.find((x) => x.id === selectedSessionInstance.id) })))));
}
exports.Schedule = Schedule;
