"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.NextUpSection = exports.NextUp = void 0;
const formatDistanceToNow_1 = __importDefault(require("date-fns/formatDistanceToNow"));
const ink_1 = require("ink");
const ms_1 = __importDefault(require("ms"));
const react_1 = __importStar(require("react"));
const useCalendar_1 = require("../../hooks/useCalendar");
const useResize_1 = require("../../hooks/useResize");
const dateHelpers_1 = require("../../utils/dateHelpers");
const Bold_1 = require("../common/Bold");
const Divider_1 = require("../common/Divider");
function retrieveNextSessions(sessions, count) {
    const currentTime = Date.now();
    const futureSessions = sessions.filter((session) => {
        return session.end_date > currentTime;
    });
    return futureSessions.slice(0, count);
}
function useNextSessions(sessions, count = 2, refreshRate = ms_1.default('1m')) {
    const sortedSessions = react_1.useMemo(() => [...sessions].sort(dateHelpers_1.sortByDate), [
        sessions.length,
    ]);
    const [nextSessions, setNextSessions] = react_1.useState(retrieveNextSessions(sortedSessions, count));
    // update times every minute
    react_1.useEffect(() => {
        const intervalId = setInterval(() => {
            const nextUpSessions = retrieveNextSessions(sortedSessions, count);
            setNextSessions(nextUpSessions);
        }, refreshRate);
        return () => {
            if (intervalId) {
                clearInterval(intervalId);
            }
        };
    }, []);
    // update if user registers for a session
    react_1.useEffect(() => {
        setNextSessions(retrieveNextSessions(sortedSessions, count));
    }, [sortedSessions.length]);
    return nextSessions;
}
function ShortSessionEntry({ session }) {
    const startTime = formatDistanceToNow_1.default(new Date(session.start_date), {
        addSuffix: true,
    });
    return (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement(ink_1.Text, { wrap: "truncate-end" },
            react_1.default.createElement(Bold_1.Bold, null,
                startTime,
                ":")),
        react_1.default.createElement(ink_1.Text, { wrap: "truncate-end" }, session.title)));
}
function NextUp({ sessions }) {
    const { ref, shouldRender } = useResize_1.useBreakpointForElement({ minHeight: 7 });
    const nextSessions = useNextSessions(sessions);
    return (react_1.default.createElement(ink_1.Box, { ref: ref, flexDirection: "column", padding: 1, height: 7 }, shouldRender && (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement(Divider_1.Divider, { title: "Next Up" }),
        nextSessions.map((session) => (react_1.default.createElement(ShortSessionEntry, { session: session, key: session.id })))))));
}
exports.NextUp = NextUp;
exports.NextUpSection = () => {
    const { error, calendar } = useCalendar_1.useCalendar();
    if (Array.isArray(calendar)) {
        return react_1.default.createElement(NextUp, { sessions: calendar });
    }
    else if (typeof error !== 'undefined') {
        return react_1.default.createElement(ink_1.Text, null, error.toString());
    }
    else {
        return null;
    }
};
