"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useDemos = exports.useApi = exports.useGot = void 0;
const react_1 = require("@xstate/react");
const got_1 = __importDefault(require("got"));
const react_2 = require("react");
const xstate_1 = require("xstate");
const config_1 = __importDefault(require("../utils/config"));
const diagnostics_1 = require("../utils/diagnostics");
const fetchMachine = xstate_1.Machine({
    id: 'fetchMachine',
    initial: 'idle',
    context: {
        data: undefined,
        error: undefined,
    },
    states: {
        idle: {
            on: {
                FETCH: 'loading',
            },
        },
        loading: {
            invoke: {
                id: 'fetch',
                src: 'fetch',
                onDone: {
                    target: 'resolved',
                    actions: xstate_1.assign({
                        data: (_, event) => event.data,
                    }),
                },
                onError: {
                    target: 'rejected',
                    actions: xstate_1.assign({
                        error: (_, event) => event.data,
                    }),
                },
            },
            on: {
                CANCEL: 'idle',
                FETCH: 'loading',
            },
        },
        resolved: {
            type: 'final',
        },
        rejected: {
            on: {
                FETCH: 'loading',
            },
        },
    },
});
function useGot(url, gotOptions = undefined) {
    const fetch = react_2.useCallback(() => {
        return got_1.default(url, Object.assign(Object.assign({}, gotOptions), { headers: {
                'user-agent': diagnostics_1.getUserAgent(),
            } })).json();
    }, [url, gotOptions]);
    const [state, dispatch] = react_1.useMachine(fetchMachine, {
        services: {
            fetch,
        },
    });
    react_2.useEffect(() => {
        dispatch('FETCH');
        return () => {
            if (state.matches('loading')) {
                dispatch('CANCEL');
            }
        };
    }, [url, gotOptions]);
    return {
        data: state.matches('resolved') ? state.context.data : undefined,
        loading: state.matches('loading'),
        error: state.matches('rejected') ? state.context.error : undefined,
    };
}
exports.useGot = useGot;
function useApi(endpoint) {
    const url = `${config_1.default.developerModeApi}${endpoint}`;
    return useGot(url);
}
exports.useApi = useApi;
function convertObjectToArray(obj) {
    if (typeof obj === 'undefined') {
        return undefined;
    }
    return Object.keys(obj).map((key) => {
        return Object.assign({ key }, obj[key]);
    });
}
function useDemos() {
    const apiResponse = useApi('/demos.json');
    const demosObject = apiResponse.data ? apiResponse.data.demos : undefined;
    const demos = convertObjectToArray(demosObject);
    return Object.assign(Object.assign({}, apiResponse), { demos });
}
exports.useDemos = useDemos;
