"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useCalendar = void 0;
const client_1 = require("@apollo/client");
const react_1 = require("react");
const calendar_1 = require("../queries/calendar");
const useSignalTv_1 = require("./useSignalTv");
function useCalendar() {
    const { signalTvSchedule } = useSignalTv_1.useSignalTv();
    const { data, error, loading } = client_1.useQuery(calendar_1.SessionsQuery);
    const joinedSessions = react_1.useMemo(() => {
        let sessions = [];
        if (data && Array.isArray(data.getPublicSessions)) {
            sessions = [...sessions, ...data.getPublicSessions];
        }
        if (Array.isArray(signalTvSchedule)) {
            sessions = [...sessions, ...signalTvSchedule];
        }
        return sessions;
    }, [data, signalTvSchedule]);
    const [registerMutation] = client_1.useMutation(calendar_1.RegisterForSessionQuery, {});
    const [unregisterMutation] = client_1.useMutation(calendar_1.UnregisterForSessionQuery, {});
    const register = react_1.useCallback((sessionId) => registerMutation({
        variables: { sessionId },
        refetchQueries: [{ query: calendar_1.SessionsQuery }],
    }), [registerMutation]);
    const unregister = react_1.useCallback((sessionId) => unregisterMutation({
        variables: { sessionId },
        refetchQueries: [{ query: calendar_1.SessionsQuery }],
    }), [unregisterMutation]);
    return {
        unregister,
        register,
        error,
        loading,
        data,
        joinedSessions,
        calendar: data === null || data === void 0 ? void 0 : data.getAttendeeCalendar,
    };
}
exports.useCalendar = useCalendar;
