"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useKeynoteInfo = void 0;
const got_1 = __importDefault(require("got"));
const react_1 = require("react");
const use_effect_reducer_1 = require("use-effect-reducer");
const config_1 = __importDefault(require("../utils/config"));
const diagnostics_1 = require("../utils/diagnostics");
const keynoteInfoEffectReducer = (state, event, exec) => {
    if (event.type === 'FETCH') {
        exec({ type: 'fetchInspectorApi' });
        return {
            status: 'loading-inspector-data',
            data: undefined,
            error: undefined,
            vttFileContent: undefined,
        };
    }
    else if (event.type === 'RECEIVED_INFO' &&
        state.status === 'loading-inspector-data') {
        exec({ type: 'fetchVttInfo' });
        return {
            status: 'loading-vtt',
            data: event.data,
            error: null,
            vttFileContent: undefined,
        };
    }
    else if (event.type === 'RECEIVED_VTT' && state.status === 'loading-vtt') {
        return {
            status: 'success',
            data: state.data,
            error: null,
            vttFileContent: event.data,
        };
    }
    else if (event.type === 'ERROR') {
        return {
            status: 'error',
            data: undefined,
            error: event.error,
            vttFileContent: undefined,
        };
    }
    return state;
};
const fetchInspectorApi = (state, effect, dispatch) => {
    got_1.default(`${config_1.default.developerModeApi}/inspector`, {
        headers: {
            'user-agent': diagnostics_1.getUserAgent(),
        },
    })
        .json()
        .then((data) => dispatch({ type: 'RECEIVED_INFO', data }))
        .catch((err) => dispatch({ type: 'ERROR', error: err }));
};
const fetchVttInfo = (state, effect, dispatch) => {
    if (state.data) {
        got_1.default(state.data.xray.closedCaptions, {
            headers: {
                'user-agent': diagnostics_1.getUserAgent(),
            },
        })
            .text()
            .then((data) => {
            dispatch({ type: 'RECEIVED_VTT', data: data });
        })
            .catch((err) => {
            dispatch({ type: 'ERROR', error: err });
        });
    }
    else {
        dispatch({ type: 'ERROR', error: new Error('Something went wrong') });
    }
};
function useKeynoteInfo() {
    const [state, dispatch] = use_effect_reducer_1.useEffectReducer(keynoteInfoEffectReducer, {
        status: 'idle',
        data: undefined,
        vttFileContent: undefined,
        error: undefined,
    }, {
        fetchInspectorApi: fetchInspectorApi,
        fetchVttInfo: fetchVttInfo,
    });
    react_1.useEffect(() => {
        dispatch({ type: 'FETCH' });
    }, []);
    return Object.assign({}, state);
}
exports.useKeynoteInfo = useKeynoteInfo;
