"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useBreakpointForWindow = exports.useBreakpointForElement = exports.shouldRenderBasedOnBreakpoint = exports.useResponsiveMeasureElement = exports.useResponsiveWindowSize = exports.useResize = void 0;
const ink_1 = require("ink");
const react_1 = require("react");
const mode_1 = require("../context/mode");
function useResize(handler) {
    const { stdout } = ink_1.useStdout();
    react_1.useEffect(() => {
        handler(stdout);
        stdout === null || stdout === void 0 ? void 0 : stdout.setMaxListeners(100);
        stdout === null || stdout === void 0 ? void 0 : stdout.on('resize', () => handler(stdout));
        return () => {
            stdout === null || stdout === void 0 ? void 0 : stdout.off('resize', () => handler(stdout));
        };
    }, [stdout]);
}
exports.useResize = useResize;
function useResponsiveWindowSize() {
    const { stdout } = ink_1.useStdout();
    const [width, setTotalWidth] = react_1.useState(stdout === null || stdout === void 0 ? void 0 : stdout.columns);
    const [height, setTotalHeight] = react_1.useState(stdout === null || stdout === void 0 ? void 0 : stdout.rows);
    useResize((stdout) => {
        if (stdout) {
            setTotalWidth(stdout.columns);
            setTotalHeight(stdout.rows);
        }
    });
    return {
        width,
        height,
    };
}
exports.useResponsiveWindowSize = useResponsiveWindowSize;
function useResponsiveMeasureElement(changeTriggers = []) {
    var _a;
    const { state } = mode_1.useMode();
    const [domNode, setDomNode] = react_1.useState(null);
    const [width, setWidth] = react_1.useState(0);
    const [height, setHeight] = react_1.useState(0);
    const [workaroundCounter, setWorkaroundCount] = react_1.useState(0);
    const { width: totalWidth, height: totalHeight } = useResponsiveWindowSize();
    const ref = react_1.useCallback((node) => {
        setDomNode(node);
    }, []);
    react_1.useEffect(() => {
        if (domNode) {
            const result = ink_1.measureElement(domNode);
            const { width, height } = result;
            if (isNaN(width) || isNaN(height)) {
                // When at first you don't succeed...
                // Try again in a few milliseconds by triggering a re-render
                // we'll only do that 2 times. Otherwise we'll set it to Infinity.
                // if you find this work around and email HACK to d.kundel+cli[at]twilio[dot]com
                // we'll mail to the first person some special goodies
                // TODO: I should figure out why this is happening
                if (workaroundCounter < 2) {
                    setTimeout(() => {
                        setWorkaroundCount((c) => c + 1);
                    }, 20);
                }
            }
            else {
                setWidth(width);
                setHeight(height);
            }
        }
    }, [
        domNode,
        (_a = domNode === null || domNode === void 0 ? void 0 : domNode.yogaNode) === null || _a === void 0 ? void 0 : _a.getChildCount(),
        totalWidth,
        totalHeight,
        state.value,
        workaroundCounter,
        ...changeTriggers,
    ]);
    return { ref, width, height };
}
exports.useResponsiveMeasureElement = useResponsiveMeasureElement;
function shouldRenderBasedOnBreakpoint({ height = undefined, minHeight = 0, maxHeight = Infinity, width = undefined, minWidth = 0, maxWidth = Infinity, minArea = 0, maxArea = Infinity, }, totalWidth, totalHeight) {
    const totalArea = totalHeight * totalWidth;
    let shouldRender = true;
    if (totalWidth < minWidth) {
        shouldRender = false;
    }
    if (totalWidth > maxWidth) {
        shouldRender = false;
    }
    if (totalHeight < minHeight) {
        shouldRender = false;
    }
    if (totalHeight > maxHeight) {
        shouldRender = false;
    }
    if (width === totalWidth) {
        shouldRender = true;
    }
    if (height === totalHeight) {
        shouldRender = true;
    }
    if (totalArea < minArea) {
        shouldRender = false;
    }
    if (totalArea > maxArea) {
        shouldRender = false;
    }
    return shouldRender;
}
exports.shouldRenderBasedOnBreakpoint = shouldRenderBasedOnBreakpoint;
function useBreakpointForElement(breakpoint, changeTriggers = []) {
    const { width, height, ref } = useResponsiveMeasureElement(changeTriggers);
    if (Array.isArray(breakpoint)) {
        const shouldRender = breakpoint.map((b) => shouldRenderBasedOnBreakpoint(b, width, height));
        return { ref, shouldRender };
    }
    const shouldRender = shouldRenderBasedOnBreakpoint(breakpoint, width, height);
    return { ref, shouldRender };
}
exports.useBreakpointForElement = useBreakpointForElement;
function useBreakpointForWindow(breakpoint) {
    const { width, height } = useResponsiveWindowSize();
    return {
        shouldRender: shouldRenderBasedOnBreakpoint(breakpoint, width, height),
        width: width,
        height: height,
    };
}
exports.useBreakpointForWindow = useBreakpointForWindow;
