"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useTerminalInfo = exports.getTerminalInfo = void 0;
const execa_1 = __importDefault(require("execa"));
const is_wsl_1 = __importDefault(require("is-wsl"));
const os_1 = __importDefault(require("os"));
const react_1 = require("react");
function getTerminalName(shell, isWindows) {
    if (process.env.TERM_PROGRAM) {
        let name = process.env.TERM_PROGRAM;
        if (process.env.TERM_PROGRAM_VERSION) {
            name = `${name} (${process.env.TERM_PROGRAM_VERSION})`;
        }
        return name;
    }
    if (process.env.WT_SESSION) {
        return 'Windows Terminal';
    }
    return isWindows ? shell : `Unknown (${shell})`;
}
function getShell(isWindows) {
    if (!isWindows) {
        return is_wsl_1.default ? 'wsl' : process.env.SHELL ? process.env.SHELL : 'unknown';
    }
    else {
        return 'windows';
    }
}
function isWindowsOs() {
    return os_1.default.type() === 'Windows_NT';
}
function isTmuxSession() {
    return typeof process.env.TMUX === 'string' && process.env.TMUX.length > 0;
}
function hasGitSupport() {
    try {
        const { failed } = execa_1.default.sync('git --version', { shell: true });
        return !failed;
    }
    catch (err) {
        return false;
    }
}
function hasMakeSupport() {
    try {
        const { failed } = execa_1.default.sync('make --version', { shell: true });
        return !failed;
    }
    catch (err) {
        return false;
    }
}
let _terminalInfo;
function getTerminalInfo() {
    if (_terminalInfo) {
        return _terminalInfo;
    }
    const isWindows = isWindowsOs();
    const shell = getShell(isWindows);
    const terminalName = getTerminalName(shell, isWindows);
    const isITerm = terminalName.startsWith('iTerm.app');
    const isGitBash = terminalName === 'mintty' && isWindows;
    const hasGit = hasGitSupport();
    const isTmux = isTmuxSession();
    const hasMake = hasMakeSupport();
    _terminalInfo = {
        terminalName,
        shell,
        isITerm,
        isWindows,
        hasGit,
        isGitBash,
        isTmux,
        hasMake,
    };
    return _terminalInfo;
}
exports.getTerminalInfo = getTerminalInfo;
function useTerminalInfo() {
    return react_1.useMemo(() => {
        return getTerminalInfo();
    }, []);
}
exports.useTerminalInfo = useTerminalInfo;
