"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.demoEntryStateMachine = exports.hasViewCode = exports.hasDownload = exports.hasQuickDeploy = exports.DemoEntryOptions = void 0;
const xstate_1 = require("xstate");
const arrayHelpers_1 = require("../utils/arrayHelpers");
var DemoEntryOptions;
(function (DemoEntryOptions) {
    DemoEntryOptions["VIEW_CODE"] = "view-code";
    DemoEntryOptions["LEARN_MORE"] = "learn-more";
    DemoEntryOptions["DOWNLOAD"] = "download";
    DemoEntryOptions["QUICK_DEPLOY"] = "quick-deploy";
})(DemoEntryOptions = exports.DemoEntryOptions || (exports.DemoEntryOptions = {}));
function hasQuickDeploy(context) {
    return (typeof context.demo !== 'undefined' && !!context.demo.quick_deploy_link);
}
exports.hasQuickDeploy = hasQuickDeploy;
function hasDownload(context) {
    if (!context.hasGit) {
        return false;
    }
    return (!!context.demo &&
        typeof context.activeLanguageIdx !== 'undefined' &&
        !context.demo.is_community &&
        context.demo.options[context.activeLanguageIdx] &&
        context.demo.options[context.activeLanguageIdx].repo_link !== null);
}
exports.hasDownload = hasDownload;
function hasViewCode(context) {
    return (!!context.demo &&
        typeof context.activeLanguageIdx !== 'undefined' &&
        context.demo.options[context.activeLanguageIdx] &&
        (context.demo.options[context.activeLanguageIdx].repo_link !== null ||
            !!context.demo.options[context.activeLanguageIdx].functions_link));
}
exports.hasViewCode = hasViewCode;
exports.demoEntryStateMachine = xstate_1.Machine({
    id: 'demoEntry',
    initial: DemoEntryOptions.LEARN_MORE,
    context: {
        demo: undefined,
        activeLanguageIdx: 0,
        hasGit: true,
    },
    on: {
        NEXT_LANGUAGE: {
            actions: [
                xstate_1.assign({
                    activeLanguageIdx: (context) => {
                        var _a;
                        return arrayHelpers_1.nextIdxWithRollover(context.activeLanguageIdx, (_a = context.demo) === null || _a === void 0 ? void 0 : _a.options);
                    },
                }),
            ],
        },
        PREV_LANGUAGE: {
            actions: [
                xstate_1.assign({
                    activeLanguageIdx: (context) => {
                        var _a;
                        return arrayHelpers_1.prevIdxWithRollover(context.activeLanguageIdx, (_a = context.demo) === null || _a === void 0 ? void 0 : _a.options);
                    },
                }),
            ],
        },
        RESET: {
            target: DemoEntryOptions.LEARN_MORE,
            actions: [
                xstate_1.assign({
                    activeLanguageIdx: 0,
                    demo: (_, event) => event.data,
                }),
            ],
        },
    },
    states: {
        [DemoEntryOptions.LEARN_MORE]: {
            on: {
                NEXT_OPTION: [
                    { target: DemoEntryOptions.VIEW_CODE, cond: hasViewCode },
                    { target: DemoEntryOptions.DOWNLOAD, cond: hasDownload },
                    { target: DemoEntryOptions.QUICK_DEPLOY, cond: hasQuickDeploy },
                    { target: DemoEntryOptions.LEARN_MORE },
                ],
                PREV_OPTION: [
                    { target: DemoEntryOptions.QUICK_DEPLOY, cond: hasQuickDeploy },
                    { target: DemoEntryOptions.DOWNLOAD, cond: hasDownload },
                    { target: DemoEntryOptions.VIEW_CODE, cond: hasViewCode },
                    { target: DemoEntryOptions.LEARN_MORE },
                ],
            },
        },
        [DemoEntryOptions.VIEW_CODE]: {
            on: {
                NEXT_OPTION: [
                    { target: DemoEntryOptions.DOWNLOAD, cond: hasDownload },
                    { target: DemoEntryOptions.QUICK_DEPLOY, cond: hasQuickDeploy },
                    { target: DemoEntryOptions.LEARN_MORE },
                ],
                PREV_OPTION: DemoEntryOptions.LEARN_MORE,
            },
        },
        [DemoEntryOptions.DOWNLOAD]: {
            on: {
                NEXT_OPTION: [
                    {
                        target: DemoEntryOptions.QUICK_DEPLOY,
                        cond: hasQuickDeploy,
                    },
                    {
                        target: DemoEntryOptions.LEARN_MORE,
                    },
                ],
                PREV_OPTION: [
                    { target: DemoEntryOptions.VIEW_CODE, cond: hasViewCode },
                    { target: DemoEntryOptions.LEARN_MORE },
                ],
            },
        },
        [DemoEntryOptions.QUICK_DEPLOY]: {
            on: {
                NEXT_OPTION: DemoEntryOptions.LEARN_MORE,
                PREV_OPTION: [
                    { target: DemoEntryOptions.DOWNLOAD, cond: hasDownload },
                    { target: DemoEntryOptions.VIEW_CODE, cond: hasViewCode },
                    { target: DemoEntryOptions.LEARN_MORE },
                ],
            },
        },
    },
});
