"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.modeMachine = exports.ModeEvents = void 0;
const xstate_1 = require("xstate");
exports.ModeEvents = {
    showWelcome: 'SHOW_WELCOME',
    showClosedCaptioning: 'SHOW_CLOSED_CAPTIONING',
    showResources: 'SHOW_RESOURCES',
    showSchedule: 'SHOW_SCHEDULE',
    showInstaller: 'SHOW_INSTALLER',
    showCheatMode: 'SHOW_CHEAT_MODE',
    showTest: 'SHOW_TEST',
    showDemos: 'SHOW_DEMOS',
    exitCheatMode: 'EXIT_CHEAT_MODE',
    exitInstaller: 'EXIT_INSTALLER',
    exit: 'EXIT',
    toggleInput: 'TOGGLE_INPUT',
    enableInput: 'ENABLE_INPUT',
    toggleSideBar: 'TOGGLE_SIDEBAR',
    finished: 'FINISHED',
};
const modeTransitions = {
    [exports.ModeEvents.showWelcome]: '#mode.mainPane.welcome',
    [exports.ModeEvents.showClosedCaptioning]: {
        target: ['#mode.mainPane.closedCaptioning'],
    },
    [exports.ModeEvents.showResources]: '#mode.mainPane.resources',
    [exports.ModeEvents.showSchedule]: '#mode.mainPane.schedule',
    [exports.ModeEvents.showInstaller]: {
        target: ['#mode.mainPane.installer', '#mode.captureInput.off'],
    },
    [exports.ModeEvents.showCheatMode]: {
        target: ['#mode.mainPane.cheatMode', '#mode.captureInput.off'],
    },
    [exports.ModeEvents.showTest]: '#mode.mainPane.test',
    [exports.ModeEvents.showDemos]: '#mode.mainPane.demos',
    [exports.ModeEvents.exit]: '#mode.mainPane.exit',
    [exports.ModeEvents.enableInput]: '#mode.captureInput.on',
};
// eslint-disable-next-line new-cap
exports.modeMachine = xstate_1.Machine({
    id: 'mode',
    type: 'parallel',
    context: {
        selectedDemo: undefined,
    },
    on: modeTransitions,
    states: {
        captureInput: {
            initial: 'on',
            states: {
                on: {
                    [exports.ModeEvents.toggleInput]: 'off',
                },
                off: {
                    [exports.ModeEvents.toggleInput]: 'on',
                },
            },
        },
        sideBar: {
            initial: 'visible',
            states: {
                visible: {
                    on: {
                        [exports.ModeEvents.toggleSideBar]: 'hidden',
                    },
                },
                hidden: {
                    on: {
                        [exports.ModeEvents.toggleSideBar]: 'visible',
                    },
                },
            },
        },
        mainPane: {
            initial: 'welcome',
            states: {
                welcome: {},
                closedCaptioning: {},
                resources: {},
                exit: {
                    type: 'final',
                },
                schedule: {},
                demos: {},
                installer: {
                    entry: [
                        xstate_1.assign({
                            selectedDemo: (context, event) => (event === null || event === void 0 ? void 0 : event.data) || context.selectedDemo,
                        }),
                    ],
                    on: {
                        [exports.ModeEvents.finished]: {
                            target: [
                                '#mode.mainPane.installer',
                                '#mode.captureInput.on',
                                '#mode.sideBar.visible',
                            ],
                        },
                        [exports.ModeEvents.exitInstaller]: {
                            target: ['#mode.mainPane.demos', '#mode.captureInput.on'],
                        },
                    },
                },
                cheatMode: {
                    on: {
                        [exports.ModeEvents.exitCheatMode]: {
                            target: ['#mode.mainPane.welcome', '#mode.captureInput.on'],
                        },
                    },
                },
                test: {},
            },
        },
    },
});
