"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.deployTwimlApp = void 0;
const serverless_api_1 = require("@twilio-labs/serverless-api");
const common_tags_1 = require("common-tags");
function getFunctionContent(twiml) {
    return common_tags_1.stripIndent `
    exports.handler = function (context, event, callback) {
      const resp = new Twilio.Response();
      resp.appendHeader('content-type', 'text/xml');
      resp.setBody(\`${twiml}\`);
      callback(null, resp);
    };
  `;
}
function deployTwimlApp(twiml, username, password, onUpdate) {
    return __awaiter(this, void 0, void 0, function* () {
        const functionContent = getFunctionContent(twiml);
        const config = {
            username,
            password,
            env: {},
            pkgJson: {},
            serviceName: 'magic-cloud',
            overrideExistingService: true,
            functionsEnv: 'demo',
            functions: [
                {
                    name: 'Code from the Cloud',
                    path: '/',
                    content: functionContent,
                    access: 'public',
                },
            ],
            assets: [],
        };
        try {
            const client = new serverless_api_1.TwilioServerlessApiClient(config);
            if (onUpdate) {
                client.on('status-update', (evt) => {
                    onUpdate(evt.message);
                });
            }
            const result = yield client.deployProject(config);
            return result;
        }
        catch (err) {
            throw new Error('Something went wrong. Try again later');
        }
    });
}
exports.deployTwimlApp = deployTwimlApp;
