"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getUserAgent = exports.getDiagnostics = exports.computeDiagnostics = void 0;
const is_ci_1 = __importDefault(require("is-ci"));
const useTerminalInfo_1 = require("../hooks/useTerminalInfo");
const logger_1 = require("./logger");
let _diagnostics;
function computeDiagnostics(cli) {
    /// @ts-ignore
    const pkgJson = require('../../package.json');
    const terminalInfo = useTerminalInfo_1.getTerminalInfo();
    _diagnostics = {
        pluginVersion: pkgJson.version,
        twilioCliVersion: cli.config.userAgent,
        terminal: terminalInfo.terminalName,
        shell: terminalInfo.shell + (terminalInfo.isTmux ? ' tmux' : ''),
        nodeVersion: process.versions.node,
        resolution: `${process.stdout.columns}x${process.stdout.rows}`,
        interactive: process.stdout.isTTY,
        ci: is_ci_1.default,
        hasGit: terminalInfo.hasGit,
        logFilePath: logger_1.loggerPath,
    };
    return _diagnostics;
}
exports.computeDiagnostics = computeDiagnostics;
function getDiagnostics() {
    return _diagnostics;
}
exports.getDiagnostics = getDiagnostics;
function getUserAgent() {
    if (!_diagnostics || Boolean(process.env.SIGNAL_NO_DIAGNOSTICS)) {
        return `plugin-signal2020`;
    }
    return `plugin-signal2020/${_diagnostics.pluginVersion} ${_diagnostics.twilioCliVersion}`;
}
exports.getUserAgent = getUserAgent;
