"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.pinoFinalHandler = exports.cliLogLevelToPinoLogLevel = exports.logger = exports.loggerPath = void 0;
const logging_1 = require("@twilio/cli-core/src/services/messaging/logging");
const fs_1 = __importDefault(require("fs"));
const is_wsl_1 = __importDefault(require("is-wsl"));
const os_1 = __importDefault(require("os"));
const path_1 = __importDefault(require("path"));
const pino_1 = __importDefault(require("pino"));
exports.loggerPath = path_1.default.join(os_1.default.tmpdir(), 'twilio-signal-dev-mode.log');
// clearing the logs from a previous execution on load.
if (!process.env.SIGNAL_PRESERVE_LOGS) {
    try {
        fs_1.default.unlinkSync(exports.loggerPath);
    }
    catch (err) {
        // no such file
    }
}
exports.logger = pino_1.default({
    base: null,
}, pino_1.default.destination({ dest: exports.loggerPath, sync: is_wsl_1.default ? true : false }));
setInterval(function () {
    try {
        exports.logger.flush();
    }
    catch (err) {
        // logger failed to flush. that's okay
    }
}, 10000).unref();
function cliLogLevelToPinoLogLevel(logLevel) {
    switch (logLevel) {
        case logging_1.LoggingLevel.debug:
            return 'debug';
        case logging_1.LoggingLevel.info:
            return 'info';
        case logging_1.LoggingLevel.warn:
            return 'warn';
        case logging_1.LoggingLevel.error:
            return 'error';
        default:
            return 'info';
    }
}
exports.cliLogLevelToPinoLogLevel = cliLogLevelToPinoLogLevel;
exports.pinoFinalHandler = pino_1.default.final(exports.logger, (err, finalLogger, evt, noExit = false) => {
    try {
        finalLogger.info(`${evt} caught`);
        if (err)
            finalLogger.error(err, 'error caused exit');
    }
    catch (err) {
        // carry on we got to leave
    }
    if (!noExit)
        process.exit(err ? 1 : 0);
});
exports.default = exports.logger;
