"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.groupSessionsByTypeOrDate = exports.isSignalTv = exports.isPaid = exports.getLevels = exports.isLive = exports.hasLiveTag = void 0;
const format_1 = __importDefault(require("date-fns/format"));
const dateHelpers_1 = require("./dateHelpers");
function hasLiveTag(session) {
    return (session.tags || []).map((x) => x.name).includes('type:Live');
}
exports.hasLiveTag = hasLiveTag;
function isLive(session) {
    const isLive = session.isLiveSession;
    if (isLive) {
        return Date.now() < session.end_date;
    }
    return isLive;
}
exports.isLive = isLive;
function getLevels(session) {
    if (!Array.isArray(session.tags)) {
        return '';
    }
    const levels = session.tags
        .map((x) => x.name)
        .filter((x) => x.startsWith('level:'))
        .map((x) => x.replace('level:', ''));
    return levels.join(',');
}
exports.getLevels = getLevels;
function isPaid(session) {
    return (session.tags || [])
        .map((x) => x.name)
        .includes('access:Paid (All Access)');
}
exports.isPaid = isPaid;
function isSignalTv(session) {
    return !!session.signalTv;
}
exports.isSignalTv = isSignalTv;
function augmentSession(session) {
    const live = hasLiveTag(session);
    const signalTv = isSignalTv(session);
    return Object.assign(Object.assign({}, session), { isLiveSession: live, canRegister: live, isSignalTv: signalTv });
}
function groupSessionsByTypeOrDate(sessions) {
    const groupedSets = {};
    for (const baseSession of sessions) {
        const session = augmentSession(baseSession);
        if (!session.isLiveSession && !session.isSignalTv) {
            if (!groupedSets['On Demand']) {
                groupedSets['On Demand'] = new Set();
            }
            groupedSets['On Demand'].add(session);
            continue;
        }
        const startDate = format_1.default(new Date(session.start_date), 'yyyy-MM-dd');
        if (!groupedSets[startDate]) {
            groupedSets[startDate] = new Set();
        }
        groupedSets[startDate].add(session);
    }
    const grouped = {};
    for (const date of Object.keys(groupedSets)) {
        if (date === 'On Demand') {
            grouped[date] = [...groupedSets[date]].sort((a, b) => a.title.localeCompare(b.title));
        }
        else {
            grouped[date] = [...groupedSets[date]].sort(dateHelpers_1.sortByDate);
        }
    }
    return grouped;
}
exports.groupSessionsByTypeOrDate = groupSessionsByTypeOrDate;
